(defvar eqc-eqc-autogen-fun-menu-items 
'(
  ('fun "check/2" "eqc-check2" ("property()" "counterexample()") "Tests the property in the case given.")
  ('fun "counterexample/0" "eqc-counterexample0" nil "Returns the last counter-example found.")
  ('fun "counterexample/1" "eqc-counterexample1" ("property()") "Tests the property in the same way as {@link quickcheck/1}, but if a test fails, then the failing test case is returned as a counterexample.")
  ('fun "current_counterexample/0" "eqc-current_counterexample0" nil "Returns the most recent counterexample found by QuickCheck.")
  ('fun "fails/1" "eqc-fails1" ("property()") "A property which succeeds when its argument fails.")
  ('fun "features/2" "eqc-features2" ("[any()]" "property()") "Attach a list of <i>features</i> to a test case, with the interpretation "this test case tests these features".")
  ('fun "numtests/2" "eqc-numtests2" ("N :: nat()" "Prop :: property()") "Property which is logically equivalent to <tt>Prop</tt>, but is tested <tt>N</tt> times rather than 100.")
  ('fun "on_output/2" "eqc-on_output2" ("Fun :: 'fun'(product(string(), [term()]), any())" "property()") "Supplies an output function to be used instead of io:format when QuickCheck generates output.")
  ('fun "on_test/2" "eqc-on_test2" ("Fun :: 'fun'(product(counterexample(), bool()), any())" "property()") "Attaches a function to a property which is called every time a test passes or fails.")
  ('fun "quickcheck/1" "eqc-quickcheck1" ("property()") "Tests the property in 100 random cases, printing a counter-example if one is found.")
  ('fun "recheck/1" "eqc-recheck1" ("Prop :: property()") "Tests the property with the <i>same</i> random number seed as the last failing call of {@link quickcheck/1}.")
))

(defvar eqc-prop-autogen-fun-menu-items 
'(
  ('fun "aggregate/2" "prop-aggregate2" ("L :: [term()]" "Prop :: property()") "A property logically equivalent to <tt>Prop</tt>, but which collects a list of values in each test, and displays the distribution of these values once testing is complete.")
  ('fun "aggregate/3" "prop-aggregate3" ("PrintMethod :: 'fun'(product([tuple(term(), int())]), any())" "L :: [term()]" "Prop :: property()") "Like {@link aggregate/2}, but allows the user to specify how the collected values should be printed.")
  ('fun "classify/3" "prop-classify3" ("bool()" "S :: term()" "Prop :: property()") "Property which is logically equivalent to <tt>Prop</tt>, but also classifies test cases and displays the distribution of test case classes when testing is complete.")
  ('fun "collect/2" "prop-collect2" ("S :: term()" "Prop :: property()") "No documentation found")
  ('fun "collect/3" "prop-collect3" ("PrintMethod :: 'fun'(product([tuple(term(), int())]), any())" "S :: term()" "Prop :: property()") "No documentation found")
  ('fun "conjunction/1" "prop-conjunction1" ("[tuple(atom(), property())]") "<tt>conjunction([{Tag1,Prop1},.")
  ('fun "disjunction/1" "prop-disjunction1" ("[property()]") "<tt>disjunction([Prop1,.")
  ('fun "equals/2" "prop-equals2" ("X :: any()" "Y :: any()") "A property which holds if X and Y are equal.")
  ('fun "measure/3" "prop-measure3" ("atom() | string()" "number() | [number()]" "property()") "Collects the values of X while testing Prop, and if all tests pass, displays statistics such as the minimum, average, and maximum values, identified by the name Name.")
  ('fun "only_top/1" "prop-only_top1" ("integer()") "A printing method for discarding all but the top N collected values.")
  ('fun "only_top/2" "prop-only_top2" ("integer()" "print_method()") "A printing method for discarding all but the top N collected values.")
  ('fun "with_title/1" "prop-with_title1" ("atom() | string()") "A printing method for collected data, which displays a title before the percentages of each value in the data.")
))

(defvar eqc-gen-autogen-fun-menu-items 
'(
  ('fun "binary/0" "gen-binary0" nil "Generates a binary of random size.")
  ('fun "binary/1" "gen-binary1" ("int()") "Generates a binary of a given size in bytes.")
  ('fun "bitstring/0" "gen-bitstring0" nil "Generates a list of bits in a bitstring.")
  ('fun "bitstring/1" "gen-bitstring1" ("int()") "Generates a bitstring of a given size in bits.")
  ('fun "bool/0" "gen-bool0" nil "Generates a random boolean.")
  ('fun "char/0" "gen-char0" nil "Generates a random character.")
  ('fun "choose/2" "gen-choose2" ("M" "N :: integer()") "Generates a number in the range M to N.")
  ('fun "constrain_shrinking/2" "gen-constrain_shrinking2" ("Valid :: 'fun'(product(New :: A, Old :: A), boolean())" "Gen :: gen(A)") "Constrain the shrinking behaviour of a generator to only consider shrinking step satisfying the given relation.")
  ('fun "default/2" "gen-default2" ("Default :: A" "gen(A)") "Adds a default value to a generator, to be chosen half the time.")
  ('fun "elements/1" "gen-elements1" ("[A]") "Generates an element of the list argument.")
  ('fun "fault/2" "gen-fault2" ('gen 'gen) "Adds a fault-generation alternative to a generator.")
  ('fun "fault_rate/3" "gen-fault_rate3" ("M :: int()" "N :: int()" "G :: gen(A)") "Specifies that faulty data should be generated by any uses of {@link fault/2} within G on M out of N occasions.")
  ('fun "frequency/1" "gen-frequency1" ("[tuple(integer(), gen(A))]") "Makes a weighted choice between the generators in its argument, such that the probability of choosing each generator is proportional to the weight paired with it.")
  ('fun "function0/1" "gen-function01" ("gen(A)") "Generates a function of no arguments with result generated by <tt>G</tt>.")
  ('fun "function1/1" "gen-function11" ("gen(A)") "Generates a function of one argument with result generated by <tt>G</tt>.")
  ('fun "function2/1" "gen-function21" ("gen(A)") "Generates a function of two arguments with result generated by <tt>G</tt>.")
  ('fun "function3/1" "gen-function31" ("gen(A)") "Generates a function of three arguments with result generated by <tt>G</tt>.")
  ('fun "function4/1" "gen-function41" ("gen(A)") "Generates a function of four arguments with result generated by <tt>G</tt>.")
  ('fun "growingelements/1" "gen-growingelements1" ("[A]") "Generates an element of the list argument.")
  ('fun "int/0" "gen-int0" nil "Generates a small integer (with absolute value bounded by the generation size).")
  ('fun "largeint/0" "gen-largeint0" nil "Generates an integer from a large range.")
  ('fun "less_faulty/2" "gen-less_faulty2" ("M :: int()" "G :: gen(A)") "Decreases the fault rate within G by a factor M.")
  ('fun "list/1" "gen-list1" ("gen(A)") "Generates a list of elements generated by its argument.")
  ('fun "more_faulty/2" "gen-more_faulty2" ("M :: int()" "G :: gen(A)") "Increases the fault rate within G by a factor M.")
  ('fun "nat/0" "gen-nat0" nil "Generates a small natural number (bounded by the generation size).")
  ('fun "no_faults/1" "gen-no_faults1" ("gen(A)") "Sets the fault rate to zero within its argument, disabling fault generation.")
  ('fun "non_empty/1" "gen-non_empty1" ("gen(A)") "Make sure that the generated value is not empty.")
  ('fun "noshrink/1" "gen-noshrink1" ("G :: gen(A)") "Generates the same values as <tt>G</tt>, but these values are never shrunk.")
  ('fun "oneof/1" "gen-oneof1" ("[gen(A)]") "Generates a value using a randomly chosen element of the list of generators.")
  ('fun "open/1" "gen-open1" ("B :: box(A)") "Opens a box created by {@link seal/1}.")
  ('fun "orderedlist/1" "gen-orderedlist1" ("G :: gen(A)") "Generates an ordered list of elements generated by <tt>G</tt>.")
  ('fun "parameter/1" "gen-parameter1" ("P :: atom()") "Generates the value of generator parameter P, or fails if P is unbound.")
  ('fun "parameter/2" "gen-parameter2" ("P :: atom()" "Default :: term()") "Generates the value of generator parameter P, or Default if P is unbound.")
  ('fun "peek/1" "gen-peek1" ("B :: box(A)") "Returns the value contained in a sealed box, before any shrinking.")
  ('fun "prop_shrinks_without_duplicates/1" "gen-prop_shrinks_without_duplicates1" ("gen(A)") "This property holds if the generator G never produces duplicate values during shrinking (except perhaps in the last failing test).")
  ('fun "real/0" "gen-real0" nil "Generates a real number.")
  ('fun "resize/2" "gen-resize2" ("Size :: integer()" "G :: gen(A)") "Binds the generation size parameter to <tt>Size</tt> within <tt>G</tt>.")
  ('fun "return/1" "gen-return1" ("X :: A") "Constructs a generator that always generates the value <tt>X</tt>.")
  ('fun "sample/1" "gen-sample1" ("G :: gen(A)") "Prints 11 values randomly generated by <tt>G</tt>, for sizes ranging from 10 to 20.")
  ('fun "sampleshrink/1" "gen-sampleshrink1" ("G :: gen(A)") "Prints a value generated by <tt>G</tt>, followed by one way of shrinking it.")
  ('fun "seal/1" "gen-seal1" ("G :: gen(A)") ""Seals" G, by generating a <i>sealed box</i> that, every time it is opened,  generates the <i>same</i> value, chosen from those generated by G.")
  ('fun "shrink_genlist/1" "gen-shrink_genlist1" ("Gs :: [gen(A)]") "Given a list of generators `Gs', builds a generator that shrinks to a sublist of elements generated from `Gs'.")
  ('fun "shrink_int/3" "gen-shrink_int3" ("M :: int()" "N :: int()" "X :: int()") "Generates the value X, and shrinks it within the range M to N.")
  ('fun "shrink_list/1" "gen-shrink_list1" ("L :: [A]") "Generates L, and shrinks to any sublist of L.")
  ('fun "shrink_without_duplicates/1" "gen-shrink_without_duplicates1" ("gen(A)") "Removes duplicate values from the shrinking search.")
  ('fun "shuffle/1" "gen-shuffle1" ("[A]") "Shuffles a list and shrinks to the unshuffled list.")
  ('fun "sublist/1" "gen-sublist1" ("[A]") "Generate a random sublist of the given list.")
  ('fun "timeout/2" "gen-timeout2" ("int()" "gen(A)") "timeout(T,G) generates using G, but with a timeout of T (in milliseconds).")
  ('fun "utf8/0" "gen-utf80" nil "Generates a random utf8 binary.")
  ('fun "vector/2" "gen-vector2" ("integer()" "G :: gen(A)") "Generates a list of the given length, with elements generated by <tt>G</tt>.")
  ('fun "weighted_default/2" "gen-weighted_default2" ("Default :: tuple(int(), A)" "tuple(int(), gen(A))") "Adds a default value to a generator, where both the default and the generator carry weights.")
  ('fun "with_parameter/3" "gen-with_parameter3" ("P :: atom()" "V :: term()" "G :: gen(A)") "Binds the parameter P to the value V within generator G.")
  ('fun "with_parameters/2" "gen-with_parameters2" ("Ps :: [tuple(atom(), term())]" "G :: gen(A)") "Binds all the parameters to the values given within the generator G.")
))

(defvar eqc-statem-autogen-fun-menu-items 
'(
  ('fun "call_features/1" "statem-call_features1" ("history()") "Returns a list of command features exercised in this test.")
  ('fun "call_features/2" "statem-call_features2" ("atom() | tuple(atom(), int())" "history()") "Returns a list of features exercised by calls to <tt>F</tt> (or <tt>F/A</tt>, if the arity is also specified).")
  ('fun "check_commands/3" "statem-check_commands3" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())") "Check the result of run_commands.")
  ('fun "check_commands/4" "statem-check_commands4" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())" "Env :: [tuple(atom(), term())]") "Like {@link check_commands/3}, but also takes the environment passed to {@link run_commands/3} as an additional parameter.")
  ('fun "command_names/1" "statem-command_names1" ("[command()]") "Returns a list of the command names used in <tt>Cmds</tt>.")
  ('fun "commands/1" "statem-commands1" ("Mod :: atom()") "Generates a list of commands, using the abstract state machine defined in module <tt>Mod</tt>.")
  ('fun "commands/2" "statem-commands2" ("Mod :: atom()" "S :: symbolic_state()") "Behaves like {@link commands/1}, but generates a list of commands starting in state S.")
  ('fun "eq/2" "statem-eq2" ("X :: term()" "Y :: term()") "Compare X and Y for equality, returns true if equal, and {X, '/=', Y} otherwise.")
  ('fun "linearizable/1" "statem-linearizable1" ("TestCase :: parallel_test_case()") "Adds calls of eqc_statem:now() before and after each command in the parallel part of the test case, which enables us to <i>observe</i> the order in which calls are made.")
  ('fun "more_commands/2" "statem-more_commands2" ("int()" "gen(A)") "Increases the expected length of command sequences generated within Gen by a factor N.")
  ('fun "parallel_commands/1" "statem-parallel_commands1" ("atom()") "Generate a parallel test case from the callbacks in the client module <tt>Mod</tt>.")
  ('fun "parallel_commands/2" "statem-parallel_commands2" ("atom()" "symbolic_state()") "Behaves like {@link parallel_commands/1}, but generates a test case starting in the state <tt>S</tt>.")
  ('fun "postconditions/3" "statem-postconditions3" ("Mod :: atom()" "Cmds :: [command()]" "Vals :: [term()]") "Given the values returned by a list of commands, checks that all pre- and postconditions are satisfied.")
  ('fun "pretty_commands/4" "statem-pretty_commands4" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())" "P :: property()") "Pretty-prints the execution history of a failing test, showing the calls made, the actual arguments and results, and (optionally) the model states.")
  ('fun "pretty_commands/5" "statem-pretty_commands5" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())" "Env :: [tuple(atom(), term())]" "P :: property()") "Like {@link pretty_commands/4}, but also takes the environment passed to {@link run_commands/3} as an additional parameter.")
  ('fun "run_commands/2" "statem-run_commands2" ("Mod :: module()" "Cmds :: [command()]") "Runs a list of commands specified by the abstract state machine in client module <tt>Mod</tt>.")
  ('fun "run_commands/3" "statem-run_commands3" ("Mod :: module()" "Cmds :: [command()]" "Env :: [tuple(atom(), term())]") "Behaves like {@link run_commands/2}, but also takes an environment containing values for additional variables that may be referred to in test cases.")
  ('fun "run_parallel_commands/2" "statem-run_parallel_commands2" ("atom()" "ParCmds :: parallel_test_case()") "Runs a parallel test case, and returns the history of the prefix, each of the parallel tasks, and the overall result.")
  ('fun "run_parallel_commands/3" "statem-run_parallel_commands3" ("atom()" "ParCmds :: parallel_test_case()" "Env :: [tuple(atom(), term())]") "Like {@link run_commands/2}, but also takes an environment binding variables, like {@link run_commands/3}.")
  ('fun "state_after/2" "statem-state_after2" ("Mod :: atom()" "Cmds :: [command()]") "Returns the symbolic state after a list of commands is run.")
  ('fun "zip/2" "statem-zip2" ("[A]" "[B]") "Zips two lists together, but accepts lists of different lengths, stopping when the shorter list stops.")
))

(defvar eqc-fsm-autogen-fun-menu-items 
'(
  ('fun "analyze/1" "fsm-analyze1" ("M :: callback_module()") "Analyzes the state machine specified in `M', to predict the frequency with which each transition is tested, taking into account the weights specified in the `weight' callback and the probability of preconditions failing specified in the `precondition_probability' callback.")
  ('fun "automate_weights/1" "fsm-automate_weights1" ("callback_module()") "Computes an appropriate set of transition weights for the transitions in a callback module, using the `priority' callback to guide the distribution of transitions.")
  ('fun "call_features/1" "fsm-call_features1" ("history()") "Returns a list of command features exercised in this test.")
  ('fun "call_features/2" "fsm-call_features2" ("atom() | tuple(atom(), int())" "history()") "Returns a list of features exercised by calls to <tt>F</tt> (or <tt>F/A</tt>, if the arity is also specified).")
  ('fun "check_commands/3" "fsm-check_commands3" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())") "Check the result of run_commands.")
  ('fun "check_commands/4" "fsm-check_commands4" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())" "Env :: [tuple(atom(), term())]") "Like {@link check_commands/3}, but also takes the environment passed to {@link run_commands/3} as an additional parameter.")
  ('fun "command_names/1" "fsm-command_names1" ("[command()]") "Returns a list of the command names used in <tt>Cmds</tt>.")
  ('fun "commands/1" "fsm-commands1" ("callback_module()") "Generates a list of commands, just like {@link eqc_statem:commands/1}.")
  ('fun "commands/2" "fsm-commands2" ("callback_module()" "tuple(state_name(), any())") "Generates a list of commands, starting from the given initial state with the given state data, just like {@link eqc_statem:commands/2}.")
  ('fun "dot/1" "fsm-dot1" ("M :: callback_module()") "Visualizes the state graph of the callback module, creating a file <tt>M.")
  ('fun "eq/2" "fsm-eq2" ("X :: term()" "Y :: term()") "Compare X and Y for equality, returns true if equal, and {X, '/=', Y} otherwise.")
  ('fun "linearizable/1" "fsm-linearizable1" ("TestCase :: parallel_test_case()") "Adds calls of eqc_statem:now() before and after each command in the parallel part of the test case, which enables us to <i>observe</i> the order in which calls are made.")
  ('fun "more_commands/2" "fsm-more_commands2" ("int()" "gen(A)") "Increases the expected length of command sequences generated within Gen by a factor N.")
  ('fun "parallel_commands/1" "fsm-parallel_commands1" ("atom()") "Generate a parallel test case from the callbacks in the client module <tt>Mod</tt>.")
  ('fun "parallel_commands/2" "fsm-parallel_commands2" ("atom()" "symbolic_state()") "Behaves like {@link parallel_commands/1}, but generates a test case starting in the state <tt>S</tt>.")
  ('fun "pretty_commands/4" "fsm-pretty_commands4" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())" "P :: property()") "Pretty-prints the execution history of a failing test, showing the calls made, the actual arguments and results, and (optionally) the model states.")
  ('fun "pretty_commands/5" "fsm-pretty_commands5" ("Mod :: atom()" "Cmds :: [command()]" "HSRes :: tuple(history(), dynamic_state(), reason())" "Env :: [tuple(atom(), term())]" "P :: property()") "Like {@link pretty_commands/4}, but also takes the environment passed to {@link run_commands/3} as an additional parameter.")
  ('fun "run_commands/2" "fsm-run_commands2" ("callback_module()" "[command()]") "Runs a list of commands generated using {@link commands/1}, just as does {@link eqc_statem:run_commands/2}.")
  ('fun "run_commands/3" "fsm-run_commands3" ("callback_module()" "[command()]" "[tuple(atom(), term())]") "Behaves like {@link run_commands/2}, but also takes an environment containing values for additional variables that may be referred to in test cases.")
  ('fun "run_parallel_commands/2" "fsm-run_parallel_commands2" ("atom()" "ParCmds :: parallel_test_case()") "Runs a parallel test case, and returns the history of the prefix, each of the parallel tasks, and the overall result.")
  ('fun "run_parallel_commands/3" "fsm-run_parallel_commands3" ("atom()" "ParCmds :: parallel_test_case()" "Env :: [tuple(atom(), term())]") "Like {@link run_commands/2}, but also takes an environment binding variables, like {@link run_commands/3}.")
  ('fun "state_after/2" "fsm-state_after2" ("callback_module()" "Cmds :: [command()]") "Returns the symbolic state after a list of commands is run.")
  ('fun "state_names/1" "fsm-state_names1" ("history()") "Extracts the state names from a history.")
  ('fun "visualize/1" "fsm-visualize1" ("callback_module()") "Visualizes the state graph of the callback module, and the transition frequencies.")
  ('fun "zip/2" "fsm-zip2" ("[A]" "[B]") "Zips two lists together, but accepts lists of different lengths, stopping when the shorter list stops.")
))

(defvar eqc-component-autogen-fun-menu-items 
'(
  ('fun "commands/1" "component-commands1" ("Mod :: atom()") "Generates a list of commands, using the abstract state machine defined in module <tt>Mod</tt>.")
  ('fun "commands/2" "component-commands2" ("Mod :: atom()" "S :: eqc_statem:symbolic_state()") "Behaves like {@link commands/1}, but generates a list of commands starting in state S.")
  ('fun "get_return_value/1" "component-get_return_value1" ("eqc_statem:metadata()") "Get return value as set by the callouts.")
  ('fun "pretty_commands/4" "component-pretty_commands4" ("Mod :: atom()" "Cmds :: [eqc_statem:command()]" "HSRes :: tuple(eqc_statem:history(), eqc_statem:dynamic_state(), eqc_statem:reason())" "P :: eqc:property()") "Pretty-prints the execution history of a failing test, showing the calls made, the actual arguments and results, and (optionally) the model states.")
  ('fun "pretty_commands/5" "component-pretty_commands5" ("Mod :: atom()" "Cmds :: [eqc_statem:command()]" "HSRes :: tuple(eqc_statem:history(), eqc_statem:dynamic_state(), eqc_statem:reason())" "Env :: [tuple(atom(), term())]" "P :: eqc:property()") "Like {@link pretty_commands/4}, but also takes the environment passed to {@link run_commands/3} as an additional parameter.")
  ('fun "pretty_commands/6" "component-pretty_commands6" ("Mod :: atom()" "Cmds :: [eqc_statem:command()]" "HSRes :: tuple(eqc_statem:history(), eqc_statem:dynamic_state(), eqc_statem:reason())" "Env :: [tuple(atom(), term())]" "ApiSpec :: api_spec() | none" "P :: eqc:property()") "Like {@link pretty_commands/5}, but takes an API specification as an additional parameter.")
  ('fun "run_commands/2" "component-run_commands2" ("Mod :: module()" "Cmds :: [eqc_statem:command()]") "Runs a list of commands specified by the abstract state machine in client module <tt>Mod</tt>.")
  ('fun "run_commands/3" "component-run_commands3" ("Mod :: module()" "Cmds :: [eqc_statem:command()]" "Env :: [tuple(atom(), term())]") "Behaves like {@link run_commands/2}, but also takes an environment containing values for additional variables that may be referred to in test cases.")
))

(defvar eqc-cluster-autogen-fun-menu-items 
'(
  ('fun "api_spec/1" "cluster-api_spec1" ("atom()") "Computes a cluster api_spec by doing a merge of the api_specs of the components.")
  ('fun "commands/1" "cluster-commands1" ("Mod :: module()") "This module provides functions for testing operations with side-effects, which are specified via a collection of abstract state machines with external interactions.")
  ('fun "commands/2" "cluster-commands2" ("Mod :: module()" "S :: [tuple(atom(), term())]") "Generates a list of commands, using the cluster defined in module <tt>Mod</tt>, where custom initial states for some or all components are given by <tt>S</tt>.")
  ('fun "run_commands/2" "cluster-run_commands2" ("Mod :: module()" "Cmds :: [eqc_statem:command()]") "Runs a list of commands specified by the cluster in client module <tt>Mod</tt>.")
  ('fun "run_commands/3" "cluster-run_commands3" ("Mod :: module()" "Cmds :: [eqc_statem:command()]" "Env :: [tuple(atom(), term())]") "Behaves like {@link run_commands/2}, but also takes an environment containing values for additional variables that may be referred to in test cases.")
))

(defvar eqc-eqcc-autogen-fun-menu-items 
'(
  ('fun "add_to_ptr/2" "eqcc-add_to_ptr2" ("ptr()" "integer()") "Add N to a pointer.")
  ('fun "address_of/1" "eqcc-address_of1" ("atom()") "Get a pointer to a C function or global variable.")
  ('fun "alloc/1" "eqcc-alloc1" ("type()") "Allocate memory for an object of type ``Type''.")
  ('fun "alloc/2" "eqcc-alloc2" ("type()" "term()") "Allocate memory for an object of type ``Type'' and initialize it to      the value ``X''.")
  ('fun "array_index/2" "eqcc-array_index2" ("ptr()" "integer()") "Return the value at the given index of an array.")
  ('fun "array_index/3" "eqcc-array_index3" ("ptr()" "integer()" "term()") "Set the value at the given index of an array.")
  ('fun "cast_ptr/2" "eqcc-cast_ptr2" ("type()" "ptr()") "Change the type of a pointer.")
  ('fun "create_array/2" "eqcc-create_array2" ("type()" "[term()]") "Allocate an array of the given type containing the values ``Xs''.")
  ('fun "create_string/1" "eqcc-create_string1" ("string()") " Allocate a C string containing the given string.")
  ('fun "deref/1" "eqcc-deref1" ("ptr()") "Dereference a pointer.")
  ('fun "expand_type/1" "eqcc-expand_type1" ("type()") "Expand all type definitions in a type.")
  ('fun "free/1" "eqcc-free1" ("ptr()") "Free the memory pointed to by a pointer.")
  ('fun "read_array/2" "eqcc-read_array2" ("ptr()" "integer()") "Read the elements of an array.")
  ('fun "read_string/1" "eqcc-read_string1" ("ptr()") "Read the value of a null terminated C string.")
  ('fun "set_value/2" "eqcc-set_value2" ("atom()" "term()") "Set the value of a global variable.")
  ('fun "sizeof/1" "eqcc-sizeof1" ("type()") "The size in bytes required to store an object of the given type.")
  ('fun "store/2" "eqcc-store2" ("ptr()" "term()") "Store a value at the location pointed to by a pointer.")
  ('fun "type_info/1" "eqcc-type_info1" ("Defined | Datatype") "Get information on a type.")
  ('fun "type_of/1" "eqcc-type_of1" ("atom()") "Get the type of a C function or global variable.")
  ('fun "type_of/2" "eqcc-type_of2" ("atom()" "bool()") "Get the type of a C function or global variable.")
  ('fun "value_of/1" "eqcc-value_of1" ("atom()") "Get the value of a global variable.")
  ('fun "write_array/2" "eqcc-write_array2" ("ptr()" "term()") "Store values in the array pointed to be the first argument.")
))

(defvar eqc-eqctemp-autogen-fun-menu-items 
'(
  ('fun "all_future/1" "eqctemp-all_future1" ("rel()") "Relate values that will stay true for eternity.")
  ('fun "all_future/2" "eqctemp-all_future2" ("time()" "rel()") "Relate values that will stay true for a given time.")
  ('fun "all_past/1" "eqctemp-all_past1" ("rel()") "Relate values that have been true since time 0.")
  ('fun "all_past/2" "eqctemp-all_past2" ("time()" "rel()") "Relate values that have been true for a given time.")
  ('fun "any_future/1" "eqctemp-any_future1" ("rel()") "Relate values that will be true at some point.")
  ('fun "any_future/2" "eqctemp-any_future2" ("time()" "rel()") "Relate values that will become true at some point within the given time.")
  ('fun "any_past/1" "eqctemp-any_past1" ("rel()") "Relate values that have been true at some point.")
  ('fun "any_past/2" "eqctemp-any_past2" ("time()" "rel()") "Relate values that have been true at some point within the given time.")
  ('fun "at/2" "eqctemp-at2" ("time()" "rel()") "Compute the values related to ``Time'' by ``R''.")
  ('fun "bind/2" "eqctemp-bind2" ("rel()" "'fun'(product(term()), rel())") "The bind operation of the temporal relation monad.")
  ('fun "coarsen/2" "eqctemp-coarsen2" ("integer()" "rel()") "Coarsen the resolution of time in a temporal relation, by the factor <tt>K</tt>.")
  ('fun "complement/1" "eqctemp-complement1" ("rel()") "The complement of a temporal relation.")
  ('fun "completion/1" "eqctemp-completion1" ("rel()") "Turn a temporal relation into a total temporal relation.")
  ('fun "constant/1" "eqctemp-constant1" ("term()") "The constant temporal relation.")
  ('fun "domain_size/1" "eqctemp-domain_size1" ("rel()") "The total time during which a temporal relation is true.")
  ('fun "elems/1" "eqctemp-elems1" ("rel()") "Flatten a set valued temporal relation.")
  ('fun "empty/0" "eqctemp-empty0" nil "The empty temporal relation.")
  ('fun "filter/2" "eqctemp-filter2" ("'fun'(product(term()), bool())" "rel()") "Filter a temporal relation by a predicate on the range.")
  ('fun "flatmap/2" "eqctemp-flatmap2" ("'fun'(product(term()), [term()])" "rel()") "Apply a list valued partial function to the values of a temporal relation.")
  ('fun "from_timed_list/1" "eqctemp-from_timed_list1" ("[tuple(time(), term())]") "Construct a temporal relation from a list of time value pairs.")
  ('fun "implies/2" "eqctemp-implies2" ("rel()" "rel()") "Relational implication.")
  ('fun "intersection/2" "eqctemp-intersection2" ("rel()" "rel()") "Intersection of two temporal relations.")
  ('fun "is_false/1" "eqctemp-is_false1" ("rel()") "Check if a temporal relation is empty.")
  ('fun "is_subrelation/2" "eqctemp-is_subrelation2" ("rel()" "rel()") "Check if a temporal relation is a subrelation of another temporal relation.")
  ('fun "is_true/1" "eqctemp-is_true1" ("rel()") "Check if a temporal relation is total.")
  ('fun "last/1" "eqctemp-last1" ("rel()") "Extend a temporal relation to include the most recently related value.")
  ('fun "map/2" "eqctemp-map2" ("'fun'(product(term()), term())" "rel()") "Apply a (partial) function to the values of a temporal relation.")
  ('fun "negation/1" "eqctemp-negation1" ("rel()") "The negation of a temporal relation.")
  ('fun "negation/2" "eqctemp-negation2" ("term()" "rel()") "The negation of a temporal relation.")
  ('fun "partition/2" "eqctemp-partition2" ("'fun'(product(term()), bool())" "rel()") "Partition a temporal relation based on its range.")
  ('fun "product/2" "eqctemp-product2" ("rel()" "rel()") "The product of two temporal relations.")
  ('fun "range/1" "eqctemp-range1" ("rel()") "The range of a temporal relation.")
  ('fun "restrict/2" "eqctemp-restrict2" ("rel()" "rel()") "Restrict a temporal relation to the domain of another temporal relation.")
  ('fun "ret/1" "eqctemp-ret1" ("term()") "A singleton temporal relation.")
  ('fun "set/1" "eqctemp-set1" ("rel()") "Converting a temporal relation to a set valued temporal relation.")
  ('fun "shift/2" "eqctemp-shift2" ("time()" "rel()") "Shift a temporal relation by a given time.")
  ('fun "slice/3" "eqctemp-slice3" ("time()" "time()" "rel()") "Restrict a temporal relation to a particular time slice.")
  ('fun "split_at/2" "eqctemp-split_at2" ("'fun'(product(term()), bool())" "rel()") "Split a temporal relation into two temporal relations with disjoint domains.")
  ('fun "stateful/3" "eqctemp-stateful3" ("'fun'(product(term()), [State])" "'fun'(product(State, term()), [State])" "rel()") "Apply a simple state machine to a temporal relation.")
  ('fun "subtract/2" "eqctemp-subtract2" ("rel()" "rel()") "Subtract one temporal relation from another.")
  ('fun "union/2" "eqctemp-union2" ("rel()" "rel()") "Union of two temporal relations.")
  ('fun "unions/1" "eqctemp-unions1" ("[rel()]") "Take the union of a list of temporal relations.")
))

(defvar eqc-eqcmock-autogen-fun-menu-items 
'(
  ('fun "check_callouts/1" "eqcmock-check_callouts1" ("MockLang :: lang(_Action, Result)") "Checks that the correct callouts have been made.")
  ('fun "get_trace/1" "eqcmock-get_trace1" ("APISpec :: api_spec()") "Returns the trace, i.")
  ('fun "info/0" "eqcmock-info0" nil "Information about what is currently being mocked.")
  ('fun "init_lang/2" "eqcmock-init_lang2" ("MockLang :: lang(_Action, _Result)" "APISpec :: api_spec()") "Initialize the mocking language.")
  ('fun "is_lang/1" "eqcmock-is_lang1" ("MockLang :: lang(_Action, _Result)") "Recognizer for the mocking language.")
  ('fun "start_mocking/2" "eqcmock-start_mocking2" ("APISpec :: record(api_spec, field_type(language, erlang))" "Components :: [atom()]") "Initialize mocking, mocked modules are created as specified in the supplied callout specification.")
  ('fun "stop_mocking/0" "eqcmock-stop_mocking0" nil "Gracefully stop mocking.")
  ('fun "validate/1" "eqcmock-validate1" ("MockLang :: lang(_Action, _Result)") "Validate a mocking language.")
))

(defvar eqc-eqcmockc-autogen-fun-menu-items 
'(
  ('fun "c_code/2" "eqcmockc-c_code2" ("Headers :: [string()]" "APISpec :: record(api_spec, field_type(language, c))") "Generates C-code for the mocked API.")
  ('fun "check_callouts/1" "eqcmockc-check_callouts1" ("MockLang :: eqc_mocking:lang(_Action, Result)") "Checks that the correct callouts have been made.")
  ('fun "gen_headers/1" "eqcmockc-gen_headers1" ("API :: record(api_spec, field_type(language, c)) | record(api_module, field_type(functions, [api_fun_c()]))") "This module provides functionality for mocking C modules/function.")
  ('fun "init_lang/2" "eqcmockc-init_lang2" ("MockLang :: eqc_mocking:lang(_Action, _Result)" "APISpec :: api_spec()") "Initialize the mocking language.")
  ('fun "start_mocking/6" "eqcmockc-start_mocking6" ("Module :: atom()" "APISpec :: api_spec()" "HeaderFiles :: [path()]" "ObjectFiles :: [path()]" "COptions :: proplists:proplist()" "Components :: [atom()]") "Initialize mocking, mocked modules are created as specified in the supplied callout specification.")
))

